import { GraphQLDirective, DirectiveLocation, GraphQLError } from 'graphql';

const GraphQLLiveDirective = new GraphQLDirective({
    name: "live",
    description: "Instruction for establishing a live connection that is updated once the underlying data changes.",
    locations: [DirectiveLocation.QUERY],
});

const isSome = (input) => input != null;

const isLiveQueryOperationDefinitionNode = (input) => {
    var _a;
    return input.kind === "OperationDefinition" &&
        input.operation === "query" &&
        isSome((_a = input.directives) === null || _a === void 0 ? void 0 : _a.find((d) => d.name.value === "live"));
};

const NoLiveMixedWithDeferStreamRule = (context) => {
    return {
        OperationDefinition(operationDefinitionNode) {
            if (isLiveQueryOperationDefinitionNode(operationDefinitionNode) === false) {
                return false;
            }
        },
        Directive(directiveNode) {
            if (directiveNode.name.value === "defer" ||
                directiveNode.name.value === "stream") {
                context.reportError(new GraphQLError(`Cannot mix "@${directiveNode.name.value}" with "@live".`, directiveNode.name));
            }
        },
    };
};

export { GraphQLLiveDirective, NoLiveMixedWithDeferStreamRule, isLiveQueryOperationDefinitionNode };
//# sourceMappingURL=index.esm.js.map
